@@ -109,7 +109,7 @@ bool CDirectoryCache::DoesExist(const CServer &server, const CServerPath &path,
 	return false;
 }
 
-bool CDirectoryCache::LookupFile(CDirentry &entry, const CServer &server, const CServerPath &path, const wxString& file, bool &dirDidExist, bool &matchedCase)
+bool CDirectoryCache::LookupFile(CDirentry &entry, CServer const& server, CServerPath const& path, std::wstring const& file, bool &dirDidExist, bool &matchedCase)
 {
 	fz::scoped_lock lock(mutex_);
 
@@ -175,7 +175,7 @@ bool CDirectoryCache::InvalidateFile(const CServer &server, const CServerPath &p
 	return true;
 }
 
-bool CDirectoryCache::UpdateFile(const CServer &server, const CServerPath &path, const wxString& filename, bool mayCreate, enum Filetype type /*=file*/, int64_t size /*=-1*/)
+bool CDirectoryCache::UpdateFile(const CServer &server, const CServerPath &path, const wxString& filename, bool mayCreate, Filetype type, int64_t size)
 {
 	fz::scoped_lock lock(mutex_);
 
@@ -205,7 +205,7 @@ bool CDirectoryCache::UpdateFile(const CServer &server, const CServerPath &path,
 		}
 
 		if (matchCase) {
-			enum Filetype old_type = entry.listing[i].is_dir() ? dir : file;
+			Filetype old_type = entry.listing[i].is_dir() ? dir : file;
 			if (type != old_type)
 				entry.listing.m_flags |= CDirectoryListing::unsure_invalid;
 			else if (type == dir)
@@ -214,7 +214,6 @@ bool CDirectoryCache::UpdateFile(const CServer &server, const CServerPath &path,
 				entry.listing.m_flags |= CDirectoryListing::unsure_file_changed;
 		}
 		else if (type != unknown && mayCreate) {
-			const unsigned int count = entry.listing.GetCount();
 			CDirentry direntry;
 			direntry.name = filename;
 			if (type == dir)
@@ -335,7 +334,7 @@ bool CDirectoryCache::GetChangeTime(fz::monotonic_clock& time, const CServer &se
 	return false;
 }
 
-void CDirectoryCache::RemoveDir(const CServer& server, const CServerPath& path, const wxString& filename, const CServerPath&)
+void CDirectoryCache::RemoveDir(CServer const& server, CServerPath const& path, std::wstring const& filename, CServerPath const&)
 {
 	fz::scoped_lock lock(mutex_);
 
@@ -343,12 +342,14 @@ void CDirectoryCache::RemoveDir(const CServer& server, const CServerPath& path,
 	// Perhaps just throw away the complete cache?
 
 	tServerIter sit = GetServerEntry(server);
-	if (sit == m_serverList.end())
+	if (sit == m_serverList.end()) {
 		return;
+	}
 
 	CServerPath absolutePath = path;
-	if (!absolutePath.AddSegment(filename))
+	if (!absolutePath.AddSegment(filename)) {
 		absolutePath.clear();
+	}
 
 	for (tCacheIter iter = sit->cacheList.begin(); iter != sit->cacheList.end(); ) {
 		auto & entry = const_cast<CCacheEntry&>(*iter);
@@ -370,38 +371,35 @@ void CDirectoryCache::RemoveDir(const CServer& server, const CServerPath& path,
 	RemoveFile(server, path, filename);
 }
 
-void CDirectoryCache::Rename(const CServer& server, const CServerPath& pathFrom, const wxString& fileFrom, const CServerPath& pathTo, const wxString& fileTo)
+void CDirectoryCache::Rename(CServer const& server, CServerPath const& pathFrom, std::wstring const& fileFrom, const CServerPath& pathTo, std::wstring const& fileTo)
 {
 	fz::scoped_lock lock(mutex_);
 
 	tServerIter sit = GetServerEntry(server);
-	if (sit == m_serverList.end())
+	if (sit == m_serverList.end()) {
 		return;
+	}
 
 	tCacheIter iter;
 	bool is_outdated = false;
 	bool found = Lookup(iter, sit, pathFrom, true, is_outdated);
 	if (found) {
 		auto & listing = const_cast<CDirectoryListing&>(iter->listing);
-		if (pathFrom == pathTo)
-		{
+		if (pathFrom == pathTo) {
 			RemoveFile(server, pathFrom, fileTo);
 			unsigned int i;
-			for (i = 0; i < listing.GetCount(); i++)
-			{
-				if (listing[i].name == fileFrom)
+			for (i = 0; i < listing.GetCount(); ++i) {
+				if (listing[i].name == fileFrom) {
 					break;
+				}
 			}
-			if (i != listing.GetCount())
-			{
-				if (listing[i].is_dir())
-				{
+			if (i != listing.GetCount()) {
+				if (listing[i].is_dir()) {
 					RemoveDir(server, pathFrom, fileFrom, CServerPath());
 					RemoveDir(server, pathFrom, fileTo, CServerPath());
 					UpdateFile(server, pathFrom, fileTo, true, dir);
 				}
-				else
-				{
+				else {
 					listing[i].name = fileTo;
 					listing[i].flags |= CDirentry::flag_unsure;
 					listing.m_flags |= CDirectoryListing::unsure_unknown;
@@ -412,9 +410,10 @@ void CDirectoryCache::Rename(const CServer& server, const CServerPath& pathFrom,
 		}
 		else {
 			unsigned int i;
-			for (i = 0; i < listing.GetCount(); i++) {
-				if (listing[i].name == fileFrom)
+			for (i = 0; i < listing.GetCount(); ++i) {
+				if (listing[i].name == fileFrom) {
 					break;
+				}
 			}
 			if (i != listing.GetCount()) {
 				if (listing[i].is_dir()) {
