@@ -1,17 +1,17 @@
 #include <filezilla.h>
 #include "serverpath.h"
 
-#define FTP_MVS_DOUBLE_QUOTE (wxChar)0xDC
+#define FTP_MVS_DOUBLE_QUOTE (wchar_t)0xDC
 
 struct CServerTypeTraits
 {
-	const wxChar* separators;
+	wchar_t const* separators;
 	bool has_root; // Root = simply separator nothing else
-	wxChar left_enclosure; // Example: VMS paths: [FOO.BAR]
-	wxChar right_enclosure;
+	wchar_t left_enclosure; // Example: VMS paths: [FOO.BAR]
+	wchar_t right_enclosure;
 	bool filename_inside_enclosure; // MVS
 	int prefixmode; //0 = normal prefix, 1 = suffix
-	wxChar separatorEscape;
+	wchar_t separatorEscape;
 	bool has_dots; // Special meaning for .. (parent) and . (self)
 	bool separator_after_prefix;
 };
@@ -30,13 +30,15 @@ static const CServerTypeTraits traits[SERVERTYPE_MAX] = {
 	{ _T("/\\"), false,    0,    0,    false, 0, 0,   true,  false } // DOS with forwardslashes
 };
 
-bool CServerPathData::operator==(const CServerPathData& cmp) const
+bool CServerPathData::operator==(CServerPathData const& cmp) const
 {
-	if (m_prefix != cmp.m_prefix)
+	if (m_prefix != cmp.m_prefix) {
 		return false;
+	}
 
-	if (m_segments != cmp.m_segments)
+	if (m_segments != cmp.m_segments) {
 		return false;
+	}
 
 	return true;
 }
@@ -46,18 +48,20 @@ CServerPath::CServerPath()
 {
 }
 
-CServerPath::CServerPath(CServerPath const& path, wxString subdir)
+CServerPath::CServerPath(CServerPath const& path, std::wstring subdir)
 	: m_type(path.m_type)
 	, m_data(path.m_data)
 {
-	if (subdir.empty())
+	if (subdir.empty()) {
 		return;
+	}
 
-	if (!ChangePath(subdir))
+	if (!ChangePath(subdir)) {
 		clear();
+	}
 }
 
-CServerPath::CServerPath(wxString const& path, ServerType type /*=DEFAULT*/)
+CServerPath::CServerPath(std::wstring const& path, ServerType type)
 	: m_type(type)
 {
 	SetPath(path);
@@ -68,99 +72,120 @@ void CServerPath::clear()
 	m_data.clear();
 }
 
-bool CServerPath::SetPath(wxString newPath)
+bool CServerPath::SetPath(std::wstring newPath)
 {
 	return SetPath(newPath, false);
 }
 
-bool CServerPath::SetPath(wxString &newPath, bool isFile)
+bool CServerPath::SetPath(std::wstring &newPath, bool isFile)
 {
-	wxString path = newPath;
-	wxString file;
+	std::wstring path = newPath;
+	std::wstring file;
 
-	if (path.empty())
+	if (path.empty()) {
 		return false;
+	}
 
 	if (m_type == DEFAULT) {
-		int pos1 = path.Find(_T(":["));
-		if (pos1 != -1) {
-			int pos2 = path.Find(']', true);
-			if (pos2 != -1 && static_cast<size_t>(pos2) == (path.Length() - 1) && !isFile)
+		size_t pos1 = path.find(L":[");
+		if (pos1 != std::wstring::npos) {
+			size_t pos2 = path.rfind(']');
+			if (pos2 != std::string::npos && pos2 == (path.size() - 1) && !isFile) {
 				m_type = VMS;
-			else if (isFile && pos2 > pos1)
+			}
+			else if (isFile && pos2 > pos1) {
 				m_type = VMS;
+			}
 		}
-		else if (path.Length() >= 3 &&
-			((path.c_str()[0] >= 'A' && path.c_str()[0] <= 'Z') || (path.c_str()[0] >= 'a' && path.c_str()[0] <= 'z')) &&
-			path.c_str()[1] == ':' && (path.c_str()[2] == '\\' || path.c_str()[2] == '/'))
-				m_type = DOS;
-		else if (path.c_str()[0] == FTP_MVS_DOUBLE_QUOTE && path.Last() == FTP_MVS_DOUBLE_QUOTE)
+		else if (path.size() >= 3 &&
+			((path[0] >= 'A' && path[0] <= 'Z') || (path[0] >= 'a' && path[0] <= 'z')) &&
+			path[1] == ':' && (path[2] == '\\' || path[2] == '/'))
+		{
+			m_type = DOS;
+		}
+		else if (path[0] == FTP_MVS_DOUBLE_QUOTE && path.back() == FTP_MVS_DOUBLE_QUOTE) {
 			m_type = MVS;
-		else if (path[0] == ':' && (pos1 = path.Mid(1).Find(':')) > 0) {
-			int slash = path.Find('/');
-			if (slash == -1 || slash > pos1)
-				m_type = VXWORKS;
 		}
-		else if (path[0] == '\\')
+		else if (path[0] == ':' && (pos1 = path.find(':'), 2) != std::wstring::npos) {
+			size_t slash = path.find('/');
+			if (slash == std::wstring::npos || slash > pos1) {
+				m_type = VXWORKS;
+			}
+		}
+		else if (path[0] == '\\') {
 			m_type = DOS_VIRTUAL;
+		}
 
-		if (m_type == DEFAULT)
+		if (m_type == DEFAULT) {
 			m_type = UNIX;
+		}
 	}
 
 	m_data.clear();
 
-	if (!ChangePath(path, isFile))
+	if (!ChangePath(path, isFile)) {
 		return false;
+	}
 
-	if (isFile)
+	if (isFile) {
 		newPath = path;
+	}
 	return true;
 }
 
-wxString CServerPath::GetPath() const
+std::wstring CServerPath::GetPath() const
 {
-	if (empty())
-		return wxString();
+	if (empty()) {
+		return std::wstring();
+	}
 
-	wxString path;
+	std::wstring path;
 
-	if (!traits[m_type].prefixmode && m_data->m_prefix)
+	if (!traits[m_type].prefixmode && m_data->m_prefix) {
 		path = *m_data->m_prefix;
+	}
 
-	if (traits[m_type].left_enclosure != 0)
+	if (traits[m_type].left_enclosure != 0) {
 		path += traits[m_type].left_enclosure;
-	if (m_data->m_segments.empty() && (!traits[m_type].has_root || !m_data->m_prefix || traits[m_type].separator_after_prefix))
+	}
+	if (m_data->m_segments.empty() && (!traits[m_type].has_root || !m_data->m_prefix || traits[m_type].separator_after_prefix)) {
 		path += traits[m_type].separators[0];
+	}
 
-	for (tConstSegmentIter iter = m_data->m_segments.begin(); iter != m_data->m_segments.end(); ++iter) {
-		const wxString& segment = *iter;
-		if (iter != m_data->m_segments.begin())
+	for (auto iter = m_data->m_segments.cbegin(); iter != m_data->m_segments.cend(); ++iter) {
+		std::wstring const& segment = *iter;
+		if (iter != m_data->m_segments.cbegin()) {
 			path += traits[m_type].separators[0];
+		}
 		else if (traits[m_type].has_root) {
-			if (!m_data->m_prefix || traits[m_type].separator_after_prefix)
+			if (!m_data->m_prefix || traits[m_type].separator_after_prefix) {
 				path += traits[m_type].separators[0];
+			}
 		}
 
 		if (traits[m_type].separatorEscape) {
-			wxString tmp = segment;
+			std::wstring tmp = segment;
 			EscapeSeparators(m_type, tmp);
 			path += tmp;
 		}
-		else
+		else {
 			path += segment;
+		}
 	}
 
-	if (traits[m_type].prefixmode && m_data->m_prefix)
+	if (traits[m_type].prefixmode && m_data->m_prefix) {
 		path += *m_data->m_prefix;
+	}
 
-	if (traits[m_type].right_enclosure != 0)
+	if (traits[m_type].right_enclosure != 0) {
 		path += traits[m_type].right_enclosure;
+	}
 
 	// DOS is strange.
 	// C: is current working dir on drive C, C:\ the drive root.
-	if ((m_type == DOS || m_type == DOS_FWD_SLASHES) && m_data->m_segments.size() == 1)
+	if ((m_type == DOS || m_type == DOS_FWD_SLASHES) && m_data->m_segments.size() == 1) {
 		path += traits[m_type].separators[0];
+	}
 
 	return path;
 }
@@ -186,37 +211,39 @@ CServerPath CServerPath::GetParent() const
 
 	parent_data.m_segments.pop_back();
 
-	if (m_type == MVS)
-		parent_data.m_prefix = fz::sparse_optional<wxString>(_T("."));
+	if (m_type == MVS) {
+		parent_data.m_prefix = fz::sparse_optional<std::wstring>(_T("."));
+	}
 
 	return parent;
 }
 
-wxString CServerPath::GetLastSegment() const
+std::wstring CServerPath::GetLastSegment() const
 {
-	if (empty() || !HasParent())
-		return wxString();
+	if (empty() || !HasParent()) {
+		return std::wstring();
+	}
 
-	if (!m_data->m_segments.empty())
+	if (!m_data->m_segments.empty()) {
 		return m_data->m_segments.back();
-	else
-		return wxString();
+	}
+	else {
+		return std::wstring();
+	}
 }
 
 // libc sprintf can be so slow at times...
-wxChar* fast_sprint_number(wxChar* s, size_t n)
+wchar_t* fast_sprint_number(wchar_t* s, size_t n)
 {
-	wxChar tmp[20]; // Long enough for 2^64-1
+	wchar_t tmp[20]; // Long enough for 2^64-1
 
-	wxChar* c = tmp;
-	do
-	{
+	wchar_t* c = tmp;
+	do {
 		*(c++) = n % 10 + '0';
 		n /= 10;
 	} while( n > 0 );
 
-	do
-	{
+	do {
 		*(s++) = *(--c);
 	} while (c != tmp);
 
@@ -225,10 +252,11 @@ wxChar* fast_sprint_number(wxChar* s, size_t n)
 
 #define tstrcpy wcscpy
 
-wxString CServerPath::GetSafePath() const
+std::wstring CServerPath::GetSafePath() const
 {
-	if (empty())
-		return wxString();
+	if (empty()) {
+		return std::wstring();
+	}
 
 	#define INTLENGTH 20 // 2^64 - 1
 
@@ -236,40 +264,39 @@ wxString CServerPath::GetSafePath() const
 		+ INTLENGTH; // Max length of prefix
 
 	len += m_data->m_prefix ? m_data->m_prefix->size() : 0;
-	for( auto const& segment : m_data->m_segments ) {
+	for (auto const& segment : m_data->m_segments) {
 		len += segment.size() + 2 + INTLENGTH;
 	}
 
-	wxString safepath;
-	{
-		wxStringBuffer start(safepath, len);
-		wxChar* t = start;
+	std::wstring safepath;
+	safepath.resize(len);
+	wchar_t * const start = &safepath[0];
+	wchar_t * t = &safepath[0];
 
-		t = fast_sprint_number(t, m_type);
+	t = fast_sprint_number(t, m_type);
+	*(t++) = ' ';
+	t = fast_sprint_number(t, m_data->m_prefix ? m_data->m_prefix->size() : 0);
+
+	if (m_data->m_prefix) {
 		*(t++) = ' ';
-		t = fast_sprint_number(t, m_data->m_prefix ? m_data->m_prefix->size() : 0);
-
-		if (m_data->m_prefix) {
-			*(t++) = ' ';
-			tstrcpy(t, m_data->m_prefix->c_str());
-			t += m_data->m_prefix->size();
-		}
-
-		for( auto const& segment : m_data->m_segments ) {
-			*(t++) = ' ';
-			t = fast_sprint_number(t, segment.size());
-			*(t++) = ' ';
-			tstrcpy(t, segment.c_str());
-			t += segment.size();
-		}
-		*t = 0;
+		tstrcpy(t, m_data->m_prefix->c_str());
+		t += m_data->m_prefix->size();
 	}
-	safepath.Shrink();
+
+	for (auto const& segment : m_data->m_segments) {
+		*(t++) = ' ';
+		t = fast_sprint_number(t, segment.size());
+		*(t++) = ' ';
+		tstrcpy(t, segment.c_str());
+		t += segment.size();
+	}
+	safepath.resize(t - start);
+	safepath.shrink_to_fit();
 
 	return safepath;
 }
 
-bool CServerPath::SetSafePath(const wxString& path)
+bool CServerPath::SetSafePath(std::wstring const& path)
 {
 	bool const ret = DoSetSafePath(path);
 	if (!ret) {
@@ -279,7 +306,7 @@ bool CServerPath::SetSafePath(const wxString& path)
 	return ret;
 }
 
-bool CServerPath::DoSetSafePath(const wxString& path)
+bool CServerPath::DoSetSafePath(std::wstring const& path)
 {
 	CServerPathData& data = m_data.get();
 	data.m_prefix.clear();
@@ -289,34 +316,33 @@ bool CServerPath::DoSetSafePath(const wxString& path)
 	// Before the optimization this function was responsible for
 	// most CPU cycles used during loading of transfer queues
 	// from file
-	const int len = (int)path.Len();
-	wxCharTypeBuffer<wxChar> buf(len + 1);
-	wxChar* begin = buf.data();
-
-	memcpy(begin, (const wxChar*)path.c_str(), (len + 1) * sizeof(wxChar));
-	wxChar* p = begin;
+	wchar_t const* const begin = path.c_str();
+	wchar_t const* const end = begin + path.size();
+	
+	wchar_t const* p = begin;
 
 	int type = 0;
-	do
-	{
-		if (*p < '0' || *p > '9')
+	do {
+		if (*p < '0' || *p > '9') {
 			return false;
+		}
 		type *= 10;
 		type += *p - '0';
 
-		if (type >= SERVERTYPE_MAX)
+		if (type >= SERVERTYPE_MAX) {
 			return false;
+		}
 		++p;
 	} while (*p != ' ');
 
-	m_type = (ServerType)type;
+	m_type = static_cast<ServerType>(type);
 	++p;
 
 	int prefix_len = 0;
-	do
-	{
-		if (*p < '0' || *p > '9')
+	do {
+		if (*p < '0' || *p > '9') {
 			return false;
+		}
 		prefix_len *= 10;
 		prefix_len += *p - '0';
 
@@ -327,8 +353,9 @@ bool CServerPath::DoSetSafePath(const wxString& path)
 	while (*p && *p != ' ');
 
 	if (!*p) {
-		if (prefix_len != 0)
+		if (prefix_len != 0) {
 			return false;
+		}
 		else {
 			// Is root directory, like / on unix like systems.
 			return true;
@@ -337,43 +364,39 @@ bool CServerPath::DoSetSafePath(const wxString& path)
 
 	++p;
 
-	if (len - (p - begin) < prefix_len)
+	if (prefix_len > end - p) {
 		return false;
-	if (prefix_len)
-	{
-		*(p + prefix_len) = 0;
-		if( *p ) {
-			data.m_prefix = fz::sparse_optional<wxString>(p);
-		}
-
+	}
+	if (prefix_len) {
+		data.m_prefix = fz::sparse_optional<std::wstring>(new std::wstring(p, p + prefix_len));
 		p += prefix_len + 1;
 	}
 
-	while (len > (p - begin))
-	{
+	while (p < end) {
 		int segment_len = 0;
-		do
-		{
-			if (*p < '0' || *p > '9')
+		do {
+			if (*p < '0' || *p > '9') {
 				return false;
+			}
 			segment_len *= 10;
 			segment_len += *p - '0';
 
-			if (segment_len > 32767) // Should be sane enough
+			if (segment_len > 32767) { // Should be sane enough
 				return false;
+			}
 			++p;
 		}
 		while (*p != ' ');
 
-		if (!segment_len)
+		if (!segment_len) {
 			return false;
+		}
 		++p;
 
-		if (len - (p - begin) < segment_len)
+		if (segment_len > end - p) {
 			return false;
-		*(p + segment_len) = 0;
-		wxString s(p);
-		data.m_segments.push_back(s);
+		}
+		data.m_segments.emplace_back(p, p + segment_len);
 
 		p += segment_len + 1;
 	}
@@ -383,8 +406,9 @@ bool CServerPath::DoSetSafePath(const wxString& path)
 
 bool CServerPath::SetType(ServerType type)
 {
-	if (!empty() && m_type != DEFAULT)
+	if (!empty() && m_type != DEFAULT) {
 		return false;
+	}
 
 	m_type = type;
 
@@ -415,7 +439,7 @@ bool CServerPath::IsSubdirOf(const CServerPath &path, bool cmpNoCase) const
 			else if( !m_data->m_prefix && path.m_data->m_prefix ) {
 				return false;
 			}
-			else if( m_data->m_prefix && path.m_data->m_prefix && m_data->m_prefix->CmpNoCase(*path.m_data->m_prefix) ) {
+			else if( m_data->m_prefix && path.m_data->m_prefix && fz::stricmp(*m_data->m_prefix, *path.m_data->m_prefix) ) {
 				return false;
 			}
 		}
@@ -431,14 +455,17 @@ bool CServerPath::IsSubdirOf(const CServerPath &path, bool cmpNoCase) const
 	tConstSegmentIter iter1 = m_data->m_segments.begin();
 	tConstSegmentIter iter2 = path.m_data->m_segments.begin();
 	while (iter1 != m_data->m_segments.end()) {
-		if (iter2 == path.m_data->m_segments.end())
+		if (iter2 == path.m_data->m_segments.end()) {
 			return true;
-		if (cmpNoCase) {
-			if (iter1->CmpNoCase(*iter2))
-				return false;
 		}
-		else if (*iter1 != *iter2)
+		if (cmpNoCase) {
+			if (fz::stricmp(*iter1, *iter2)) {
+				return false;
+			}
+		}
+		else if (*iter1 != *iter2) {
 			return false;
+		}
 
 		++iter1;
 		++iter2;
@@ -452,13 +479,13 @@ bool CServerPath::IsParentOf(const CServerPath &path, bool cmpNoCase) const
 	return path.IsSubdirOf(*this, cmpNoCase);
 }
 
-bool CServerPath::ChangePath(wxString subdir)
+bool CServerPath::ChangePath(std::wstring const& subdir)
 {
-	wxString subdir2 = subdir;
+	std::wstring subdir2 = subdir;
 	return ChangePath(subdir2, false);
 }
 
-bool CServerPath::ChangePath(wxString &subdir, bool isFile)
+bool CServerPath::ChangePath(std::wstring &subdir, bool isFile)
 {
 	bool ret = DoChangePath(subdir, isFile);
 	if (!ret) {
@@ -468,16 +495,18 @@ bool CServerPath::ChangePath(wxString &subdir, bool isFile)
 	return ret;
 }
 
-bool CServerPath::DoChangePath(wxString &subdir, bool isFile)
+bool CServerPath::DoChangePath(std::wstring &subdir, bool isFile)
 {
-	wxString dir = subdir;
-	wxString file;
+	std::wstring dir = subdir;
+	std::wstring file;
 
 	if (dir.empty()) {
-		if (empty() || isFile)
+		if (empty() || isFile) {
 			return false;
-		else
+		}
+		else {
 			return true;
+		}
 	}
 
 	bool const was_empty = empty();
@@ -487,238 +516,275 @@ bool CServerPath::DoChangePath(wxString &subdir, bool isFile)
 	{
 	case VMS:
 		{
-			int pos1 = dir.Find(traits[m_type].left_enclosure);
-			if (pos1 == -1)
-			{
-				int pos2 = dir.Find(traits[m_type].right_enclosure, true);
-				if (pos2 != -1)
+			size_t pos1 = dir.find(traits[m_type].left_enclosure);
+			if (pos1 == std::wstring::npos) {
+				size_t pos2 = dir.rfind(traits[m_type].right_enclosure);
+				if (pos2 != std::wstring::npos) {
 					return false;
+				}
 
-				if (isFile)
-				{
-					if (was_empty)
+				if (isFile) {
+					if (was_empty) {
 						return false;
+					}
 
 					file = dir;
 					break;
 				}
 			}
-			else
-			{
-				int pos2 = dir.Find(traits[m_type].right_enclosure, true);
-				if (pos2 == -1 || pos2 <= pos1 + 1)
+			else {
+				size_t pos2 = dir.rfind(traits[m_type].right_enclosure);
+				if (pos2 == std::wstring::npos || pos2 <= pos1 + 1) {
 					return false;
+				}
 
-				bool enclosure_is_last = static_cast<size_t>(pos2) == (dir.Length() - 1);
-				if (isFile == enclosure_is_last)
+				bool enclosure_is_last = pos2 == (dir.size() - 1);
+				if (isFile == enclosure_is_last) {
 					return false;
+				}
 
-				if (isFile)
-					file = dir.Mid(pos2 + 1);
-				dir = dir.Left(pos2);
+				if (isFile) {
+					file = dir.substr(pos2 + 1);
+				}
+				dir = dir.substr(0, pos2);
 
-				if (pos1)
-					data.m_prefix = fz::sparse_optional<wxString>(dir.Left(pos1));
-				dir = dir.Mid(pos1 + 1);
+				if (pos1) {
+					data.m_prefix = fz::sparse_optional<std::wstring>(dir.substr(0, pos1));
+				}
+				dir = dir.substr(pos1 + 1);
 
 				data.m_segments.clear();
 			}
 
-			if (!Segmentize(dir, data.m_segments))
+			if (!Segmentize(dir, data.m_segments)) {
 				return false;
-			if (data.m_segments.empty() && was_empty)
+			}
+			if (data.m_segments.empty() && was_empty) {
 				return false;
+			}
 		}
 		break;
 	case DOS:
 	case DOS_FWD_SLASHES:
 		{
-			bool is_relative = false;
-			int sep = dir.find_first_of(traits[m_type].separators);
-			if (sep == -1)
-				sep = dir.Len();
-			int colon = dir.Find(':');
-			if (colon > 0 && colon == sep - 1)
-				is_relative = true;
-
-			if (is_relative)
-				data.m_segments.clear();
-			else if (wxString(traits[m_type].separators).Contains(dir[0]))
-			{
-				if (data.m_segments.empty())
-					return false;
-				wxString first = data.m_segments.front();
-				data.m_segments.clear();
-				data.m_segments.push_back(first);
-				dir = dir.Mid(1);
+			bool is_absolute = false;
+			size_t sep = dir.find_first_of(traits[m_type].separators);
+			if (sep == std::wstring::npos) {
+				sep = dir.size();
+			}
+			size_t colon = dir.find(':');
+			if (colon != std::wstring::npos && colon > 0 && colon == sep - 1) {
+				is_absolute = true;
 			}
 
-			if (isFile && !ExtractFile(dir, file))
-				return false;
+			if (is_absolute) {
+				data.m_segments.clear();
+			}
+			else if (IsSeparator(dir[0])) {
+				// Drive-relative path
+				if (data.m_segments.empty()) {
+					return false;
+				}
+				std::wstring first = data.m_segments.front();
+				data.m_segments.clear();
+				data.m_segments.push_back(first);
+				dir = dir.substr(1);
+			}
+			// else: Any other relative path
 
-			if (!Segmentize(dir, data.m_segments))
+			if (isFile && !ExtractFile(dir, file)) {
 				return false;
-			if (data.m_segments.empty() && was_empty)
+			}
+
+			if (!Segmentize(dir, data.m_segments)) {
 				return false;
+			}
+			if (data.m_segments.empty() && was_empty) {
+				return false;
+			}
 		}
 		break;
 	case MVS:
 		{
 			// Remove the double quoation some servers send in PWD reply
-			int i = 0;
-			wxChar c = dir.c_str()[i];
-			while (c == FTP_MVS_DOUBLE_QUOTE)
-				c = dir.c_str()[++i];
-			dir.Remove(0, i);
+			size_t i = 0;
+			wchar_t c = dir[i];
+			while (c == FTP_MVS_DOUBLE_QUOTE) {
+				c = dir[++i];
+			}
+			dir.erase(0, i);
 
 			while (!dir.empty()) {
-				c = dir.Last();
-				if (c != FTP_MVS_DOUBLE_QUOTE)
+				c = dir.back();
+				if (c != FTP_MVS_DOUBLE_QUOTE) {
 					break;
-				else
-					dir.RemoveLast();
+				}
+				else {
+					dir.pop_back();
+				}
 			}
 		}
-		if (dir.empty())
+		if (dir.empty()) {
 			return false;
+		}
 
-		if (dir.c_str()[0] == traits[m_type].left_enclosure) {
-			if (dir.Last() != traits[m_type].right_enclosure)
+		if (dir[0] == traits[m_type].left_enclosure) {
+			if (dir.back() != traits[m_type].right_enclosure) {
 				return false;
+			}
 
-			dir.RemoveLast();
-			dir = dir.Mid(1);
+			dir = dir.substr(1, dir.size() - 2);
 
 			data.m_segments.clear();
 		}
-		else if (dir.Last() == traits[m_type].right_enclosure)
+		else if (dir.back() == traits[m_type].right_enclosure) {
 			return false;
-		else if (was_empty)
+		}
+		else if (was_empty) {
 			return false;
+		}
 
-		if (!dir.empty() && dir.Last() == ')') {
+		if (!dir.empty() && dir.back() == ')') {
 			// Partitioned dataset member
-			if (!isFile)
+			if (!isFile) {
 				return false;
+			}
 
-			int pos = dir.Find('(');
-			if (pos == -1)
+			size_t pos = dir.find('(');
+			if (pos == std::wstring::npos) {
 				return false;
-			dir.RemoveLast();
-			file = dir.Mid(pos + 1);
-			dir = dir.Left(pos);
+			}
+			dir.pop_back();
+			file = dir.substr(pos + 1);
+			dir = dir.substr(0, pos);
 
-			if (!was_empty && !data.m_prefix && !dir.empty())
+			if (!was_empty && !data.m_prefix && !dir.empty()) {
 				return false;
+			}
 
 			data.m_prefix.clear();
 		}
 		else {
-			if (!was_empty && !data.m_prefix)
-			{
-				if (dir.Find('.') != -1 || !isFile)
+			if (!was_empty && !data.m_prefix) {
+				if (dir.find('.') != std::wstring::npos || !isFile) {
 					return false;
+				}
 			}
 
 			if (isFile) {
-				if (!ExtractFile(dir, file))
+				if (!ExtractFile(dir, file)) {
 					return false;
-				data.m_prefix = fz::sparse_optional<wxString>(_T("."));
+				}
+				data.m_prefix = fz::sparse_optional<std::wstring>(L".");
 			}
-			else if (!dir.empty() && dir.Last() == '.')
-				data.m_prefix = fz::sparse_optional<wxString>(_T("."));
-			else
+			else if (!dir.empty() && dir.back() == '.') {
+				data.m_prefix = fz::sparse_optional<std::wstring>(L".");
+			}
+			else {
 				data.m_prefix.clear();
+			}
 		}
 
-		if (!Segmentize(dir, data.m_segments))
+		if (!Segmentize(dir, data.m_segments)) {
 			return false;
+		}
 		break;
 	case HPNONSTOP:
-		if (dir[0] == '\\')
+		if (dir[0] == '\\') {
 			data.m_segments.clear();
+		}
 
-		if (isFile && !ExtractFile(dir, file))
+		if (isFile && !ExtractFile(dir, file)) {
 			return false;
+		}
 
-		if (!Segmentize(dir, data.m_segments))
+		if (!Segmentize(dir, data.m_segments)) {
 			return false;
-		if (data.m_segments.empty() && was_empty)
+		}
+		if (data.m_segments.empty() && was_empty) {
 			return false;
+		}
 
 		break;
 	case VXWORKS:
 		{
-			if (dir[0] != ':')
-			{
-				if (was_empty)
+			if (dir[0] != ':') {
+				if (was_empty) {
 					return false;
+				}
 			}
-			else
-			{
-				int colon2;
-				if ((colon2 = dir.Mid(1).Find(':')) < 1)
+			else {
+				size_t colon2 =  dir.find(':', 1);
+				if (colon2 == std::wstring::npos || colon2 == 1) {
 					return false;
-				data.m_prefix = fz::sparse_optional<wxString>(dir.Left(colon2 + 2));
-				dir = dir.Mid(colon2 + 2);
+				}
+				data.m_prefix = fz::sparse_optional<std::wstring>(dir.substr(0, colon2 + 1));
+				dir = dir.substr(colon2 + 1);
 
 				data.m_segments.clear();
 			}
 
-			if (isFile && !ExtractFile(dir, file))
+			if (isFile && !ExtractFile(dir, file)) {
 				return false;
+			}
 
-			if (!Segmentize(dir, data.m_segments))
+			if (!Segmentize(dir, data.m_segments)) {
 				return false;
+			}
 		}
 		break;
 	case CYGWIN:
 		{
-			if (wxString(traits[m_type].separators).Contains(dir[0]))
-			{
+			if (IsSeparator(dir[0])) {
 				data.m_segments.clear();
 				data.m_prefix.clear();
 			}
-			else if (was_empty)
+			else if (was_empty) {
 				return false;
-			if (dir.Left(2) == _T("//"))
-			{
-				data.m_prefix = fz::sparse_optional<wxString>(traits[m_type].separators[0]);
-				dir = dir.Mid(1);
+			}
+			if (dir[0] == '/' && dir[1] == '/') {
+				data.m_prefix = fz::sparse_optional<std::wstring>(std::wstring(1, traits[m_type].separators[0]));
+				dir = dir.substr(1);
 			}
 
-			if (isFile && !ExtractFile(dir, file))
+			if (isFile && !ExtractFile(dir, file)) {
 				return false;
+			}
 
-			if (!Segmentize(dir, data.m_segments))
+			if (!Segmentize(dir, data.m_segments)) {
 				return false;
+			}
 		}
 		break;
 	default:
 		{
-			if (wxString(traits[m_type].separators).Contains(dir[0]))
+			if (IsSeparator(dir[0])) {
 				data.m_segments.clear();
-			else if (was_empty)
+			}
+			else if (was_empty) {
 				return false;
+			}
 
-			if (isFile && !ExtractFile(dir, file))
+			if (isFile && !ExtractFile(dir, file)) {
 				return false;
+			}
 
-			if (!Segmentize(dir, data.m_segments))
+			if (!Segmentize(dir, data.m_segments)) {
 				return false;
+			}
 		}
 		break;
 	}
 
-	if (!traits[m_type].has_root && data.m_segments.empty())
+	if (!traits[m_type].has_root && data.m_segments.empty()) {
 		return false;
+	}
 
-	if (isFile)
-	{
-		if (traits[m_type].has_dots)
-		{
-			if (file == _T("..") || file == _T("."))
+	if (isFile) {
+		if (traits[m_type].has_dots) {
+			if (file == L".." || file == L".") {
 				return false;
+			}
 		}
 		subdir = file;
 	}
@@ -768,56 +834,63 @@ bool CServerPath::operator<(const CServerPath &op) const
 
 	tConstSegmentIter iter1, iter2;
 	for (iter1 = m_data->m_segments.begin(), iter2 = op.m_data->m_segments.begin(); iter1 != m_data->m_segments.end(); ++iter1, ++iter2) {
-		if (iter2 == op.m_data->m_segments.end())
+		if (iter2 == op.m_data->m_segments.end()) {
 			return false;
+		}
 
-		const int cmp = iter1->Cmp(*iter2);
-		if (cmp < 0)
+		const int cmp = std::wcscmp(iter1->c_str(), iter2->c_str());
+		if (cmp < 0) {
 			return true;
-		if (cmp > 0)
+		}
+		if (cmp > 0) {
 			return false;
+		}
 	}
 
 	return iter2 != op.m_data->m_segments.end();
 }
 
-wxString CServerPath::FormatFilename(const wxString &filename, bool omitPath /*=false*/) const
+std::wstring CServerPath::FormatFilename(std::wstring const& filename, bool omitPath) const
 {
-	if (empty())
+	if (empty() || filename.empty()) {
 		return filename;
+	}
 
-	if (filename.empty())
-		return wxString();
-
-	if (omitPath && (!traits[m_type].prefixmode || (m_data->m_prefix && *m_data->m_prefix == _T("."))))
+	if (omitPath && (!traits[m_type].prefixmode || (m_data->m_prefix && *m_data->m_prefix == L"."))) {
 		return filename;
+	}
 
-	wxString result = GetPath();
-	if (traits[m_type].left_enclosure && traits[m_type].filename_inside_enclosure)
-		result.RemoveLast();
+	std::wstring result = GetPath();
+	if (traits[m_type].left_enclosure && traits[m_type].filename_inside_enclosure) {
+		result.pop_back();
+	}
 
-	switch (m_type)
-	{
+	switch (m_type) {
 		case VXWORKS:
-			if (!result.empty() && !wxString(traits[m_type].separators).Contains(result.Last()) && !m_data->m_segments.empty())
+			if (!result.empty() && !IsSeparator(result.back()) && !m_data->m_segments.empty()) {
 				result += traits[m_type].separators[0];
+			}
 			break;
 		case VMS:
 		case MVS:
 			break;
 		default:
-			if (!result.empty() && !wxString(traits[m_type].separators).Contains(result.Last()))
+			if (!result.empty() && !IsSeparator(result.back())) {
 				result += traits[m_type].separators[0];
+			}
 			break;
 	}
 
-	if (traits[m_type].prefixmode == 1 && !m_data->m_prefix)
-		result += _T("(") + filename + _T(")");
-	else
+	if (traits[m_type].prefixmode == 1 && !m_data->m_prefix) {
+		result += L"(" + filename + L")";
+	}
+	else {
 		result += filename;
+	}
 
-	if (traits[m_type].left_enclosure && traits[m_type].filename_inside_enclosure)
+	if (traits[m_type].left_enclosure && traits[m_type].filename_inside_enclosure) {
 		result += traits[m_type].right_enclosure;
+	}
 
 	return result;
 }
@@ -839,18 +912,20 @@ int CServerPath::CmpNoCase(const CServerPath &op) const
 	tConstSegmentIter iter = m_data->m_segments.begin();
 	tConstSegmentIter iter2 = op.m_data->m_segments.begin();
 	while (iter != m_data->m_segments.end()) {
-		int res = iter++->CmpNoCase(*iter2++);
-		if (res)
+		int res = fz::stricmp(*(iter++), *(iter2++));
+		if (res) {
 			return res;
+		}
 	}
 
 	return 0;
 }
 
-bool CServerPath::AddSegment(const wxString& segment)
+bool CServerPath::AddSegment(std::wstring const& segment)
 {
-	if (empty())
+	if (empty()) {
 		return false;
+	}
 
 	// TODO: Check for invalid characters
 	m_data.get().m_segments.push_back(segment);
@@ -923,18 +998,19 @@ CServerPath CServerPath::GetCommonParent(const CServerPath& path) const
 	return parent;
 }
 
-wxString CServerPath::FormatSubdir(const wxString &subdir) const
+std::wstring CServerPath::FormatSubdir(std::wstring const& subdir) const
 {
-	if (!traits[m_type].separatorEscape)
+	if (!traits[m_type].separatorEscape) {
 		return subdir;
+	}
 
-	wxString res = subdir;
+	std::wstring res = subdir;
 	EscapeSeparators(m_type, res);
 
 	return res;
 }
 
-bool CServerPath::SegmentizeAddSegment(wxString & segment, tSegmentList& segments, bool& append)
+bool CServerPath::SegmentizeAddSegment(std::wstring & segment, tSegmentList& segments, bool& append)
 {
 	if (traits[m_type].has_dots) {
 		if (segment == _T("."))
@@ -950,7 +1026,7 @@ bool CServerPath::SegmentizeAddSegment(wxString & segment, tSegmentList& segment
 	}
 
 	bool append_next = false;
-	if (!segment.empty() && traits[m_type].separatorEscape && segment.Last() == traits[m_type].separatorEscape) {
+	if (!segment.empty() && traits[m_type].separatorEscape && segment.back() == traits[m_type].separatorEscape) {
 		append_next = true;
 		segment[segment.size() - 1] = traits[m_type].separators[0];
 	}
@@ -965,7 +1041,7 @@ bool CServerPath::SegmentizeAddSegment(wxString & segment, tSegmentList& segment
 	return true;
 }
 
-bool CServerPath::Segmentize(wxString const& str, tSegmentList& segments)
+bool CServerPath::Segmentize(std::wstring const& str, tSegmentList& segments)
 {
 	bool append = false;
 	size_t start = 0;
@@ -981,7 +1057,7 @@ bool CServerPath::Segmentize(wxString const& str, tSegmentList& segments)
 			continue;
 		}
 
-		wxString segment = str.substr(start, pos - start);
+		std::wstring segment = str.substr(start, pos - start);
 		start = pos + 1;
 
 		if (!SegmentizeAddSegment(segment, segments, append)) {
@@ -990,7 +1066,7 @@ bool CServerPath::Segmentize(wxString const& str, tSegmentList& segments)
 	}
 
 	if (start < str.size()) {
-		wxString segment = str.substr(start);
+		std::wstring segment = str.substr(start);
 		if (!SegmentizeAddSegment(segment, segments, append)) {
 			return false;
 		}
@@ -1002,33 +1078,46 @@ bool CServerPath::Segmentize(wxString const& str, tSegmentList& segments)
 	return true;
 }
 
-bool CServerPath::ExtractFile(wxString& dir, wxString& file)
+bool CServerPath::ExtractFile(std::wstring& dir, std::wstring& file)
 {
-	int pos = dir.find_last_of(traits[m_type].separators);
-	if (pos == (int)dir.Length() - 1)
+	size_t pos = dir.find_last_of(traits[m_type].separators);
+	if (pos != std::wstring::npos && pos == dir.size() - 1) {
 		return false;
+	}
 
-	if (pos == -1) {
+	if (pos == std::wstring::npos) {
 		file = dir;
 		dir.clear();
 		return true;
 	}
 
-	file = dir.Mid(pos + 1);
-	dir = dir.Left(pos + 1);
+	file = dir.substr(pos + 1);
+	dir = dir.substr(0, pos + 1);
 
 	return true;
 }
 
-void CServerPath::EscapeSeparators(ServerType type, wxString& subdir)
+void CServerPath::EscapeSeparators(ServerType type, std::wstring& subdir)
 {
 	if (traits[type].separatorEscape) {
-		for (const wxChar* p = traits[type].separators; *p; ++p)
-			subdir.Replace((wxString)*p, (wxString)traits[type].separatorEscape + traits[type].separators[0]);
+		for (wchar_t const* p = traits[type].separators; *p; ++p) {
+			fz::replace_substrings(subdir, std::wstring(1, *p), std::wstring(1, traits[type].separatorEscape) + traits[type].separators[0]);
+		}
 	}
 }
 
 size_t CServerPath::SegmentCount() const
 {
 	return empty() ? 0 : m_data->m_segments.size();
-}
\ No newline at end of file
+}
+
+bool CServerPath::IsSeparator(wchar_t c) const
+{
+	for (wchar_t const* ref = traits[m_type].separators; *ref; ++ref) {
+		if (*ref == c) {
+			return true;
+		}
+	}
+
+	return false;
+}
