@@ -4,20 +4,25 @@
 #include <memory>
 
 class CDirectoryCache;
-class CEventLoop;
 class COptionsBase;
 class CPathCache;
 class CRateLimiter;
 
+namespace fz {
+class event_loop;
+class thread_pool;
+}
+
 // There can be multiple engines, but there can be at most one context
-class CFileZillaEngineContext
+class CFileZillaEngineContext final
 {
 public:
 	CFileZillaEngineContext(COptionsBase & options);
 	~CFileZillaEngineContext();
 
 	COptionsBase& GetOptions();
-	CEventLoop& GetEventLoop();
+	fz::thread_pool& GetThreadPool();
+	fz::event_loop& GetEventLoop();
 	CRateLimiter& GetRateLimiter();
 	CDirectoryCache& GetDirectoryCache();
 	CPathCache& GetPathCache();
