@@ -11,8 +11,8 @@ enum class lib_dependency
 	count
 };
 
-wxString GetDependencyName(lib_dependency d);
-wxString GetDependencyVersion(lib_dependency d);
+std::wstring GetDependencyName(lib_dependency d);
+std::wstring GetDependencyVersion(lib_dependency d);
 
 std::string ListTlsCiphers(std::string const& priority);
 
@@ -37,4 +37,12 @@ unique_static_cast(std::unique_ptr<Base>&& p)
 
 std::wstring url_encode(std::wstring const& s, bool keep_slashes = false);
 
-#endif //__MISC_H__
+#if FZ_WINDOWS
+DWORD GetSystemErrorCode();
+fz::native_string GetSystemErrorDescription(DWORD err);
+#else
+int GetSystemErrorCode();
+fz::native_string GetSystemErrorDescription(int err);
+#endif
+
+#endif
