@@ -62,10 +62,10 @@ void CNewBookmarkDialog::OnOK(wxCommandEvent&)
 
 	CServerPath remote_path;
 	if (!remote_path_raw.empty()) {
-		if (!global && m_server)
+		if (!global && m_server) {
 			remote_path.SetType(m_server->GetType());
-		if (!remote_path.SetPath(remote_path_raw))
-		{
+		}
+		if (!remote_path.SetPath(remote_path_raw.ToStdWstring())) {
 			wxMessageBoxEx(_("Could not parse remote path."), _("New bookmark"), wxICON_EXCLAMATION);
 			return;
 		}
@@ -174,27 +174,32 @@ void CBookmarksDialog::LoadGlobalBookmarks()
 	for (auto bookmark = element.child("Bookmark"); bookmark; bookmark = bookmark.next_sibling("Bookmark")) {
 		wxString name;
 		wxString local_dir;
-		wxString remote_dir_raw;
+		std::wstring remote_dir_raw;
 		CServerPath remote_dir;
 
 		name = GetTextElement(bookmark, "Name");
-		if (name.empty())
+		if (name.empty()) {
 			continue;
+		}
 
 		local_dir = GetTextElement(bookmark, "LocalDir");
 		remote_dir_raw = GetTextElement(bookmark, "RemoteDir");
 		if (!remote_dir_raw.empty()) {
-			if (!remote_dir.SetSafePath(remote_dir_raw))
+			if (!remote_dir.SetSafePath(remote_dir_raw)) {
 				continue;
+			}
 		}
-		if (local_dir.empty() && remote_dir.empty())
+		if (local_dir.empty() && remote_dir.empty()) {
 			continue;
+		}
 
 		bool sync;
-		if (local_dir.empty() || remote_dir.empty())
+		if (local_dir.empty() || remote_dir.empty()) {
 			sync = false;
-		else
+		}
+		else {
 			sync = GetTextElementBool(bookmark, "SyncBrowsing");
+		}
 
 		bool const comparison = GetTextElementBool(bookmark, "DirectoryComparison");
 
@@ -404,9 +409,10 @@ bool CBookmarksDialog::Verify()
 	wxString const remotePathRaw = xrc_call(*this, "ID_BOOKMARK_REMOTEDIR", &wxTextCtrl::GetValue);
 	if (!remotePathRaw.empty()) {
 		CServerPath remotePath;
-		if (server)
+		if (server) {
 			remotePath.SetType(server->GetType());
-		if (!remotePath.SetPath(remotePathRaw)) {
+		}
+		if (!remotePath.SetPath(remotePathRaw.ToStdWstring())) {
 			xrc_call(*this, "ID_BOOKMARK_REMOTEDIR", &wxTextCtrl::SetFocus);
 			if (server) {
 				wxString msg;
@@ -459,7 +465,7 @@ void CBookmarksDialog::UpdateBookmark()
 	if (!remotePathRaw.empty()) {
 		if (server)
 			data->m_remote_dir.SetType(server->GetType());
-		data->m_remote_dir.SetPath(remotePathRaw);
+		data->m_remote_dir.SetPath(remotePathRaw.ToStdWstring());
 	}
 
 	data->m_local_dir = xrc_call(*this, "ID_BOOKMARK_LOCALDIR", &wxTextCtrl::GetValue);
@@ -704,7 +710,7 @@ bool CBookmarksDialog::GetGlobalBookmarks(std::list<wxString> &bookmarks)
 	for (auto bookmark = element.child("Bookmark"); bookmark; bookmark = bookmark.next_sibling("Bookmark")) {
 		wxString name;
 		wxString local_dir;
-		wxString remote_dir_raw;
+		std::wstring remote_dir_raw;
 		CServerPath remote_dir;
 
 		name = GetTextElement(bookmark, "Name");
@@ -714,11 +720,13 @@ bool CBookmarksDialog::GetGlobalBookmarks(std::list<wxString> &bookmarks)
 		local_dir = GetTextElement(bookmark, "LocalDir");
 		remote_dir_raw = GetTextElement(bookmark, "RemoteDir");
 		if (!remote_dir_raw.empty()) {
-			if (!remote_dir.SetSafePath(remote_dir_raw))
+			if (!remote_dir.SetSafePath(remote_dir_raw)) {
 				continue;
+			}
 		}
-		if (local_dir.empty() && remote_dir.empty())
+		if (local_dir.empty() && remote_dir.empty()) {
 			continue;
+		}
 
 		bookmarks.push_back(name);
 	}
@@ -739,24 +747,29 @@ bool CBookmarksDialog::GetBookmark(const wxString &name, wxString &local_dir, CS
 	}
 
 	for (auto bookmark = element.child("Bookmark"); bookmark; bookmark = bookmark.next_sibling("Bookmark")) {
-		wxString remote_dir_raw;
+		std::wstring remote_dir_raw;
 
-		if (name != GetTextElement(bookmark, "Name"))
+		if (name != GetTextElement(bookmark, "Name")) {
 			continue;
+		}
 
 		local_dir = GetTextElement(bookmark, "LocalDir");
 		remote_dir_raw = GetTextElement(bookmark, "RemoteDir");
 		if (!remote_dir_raw.empty()) {
-			if (!remote_dir.SetSafePath(remote_dir_raw))
+			if (!remote_dir.SetSafePath(remote_dir_raw)) {
 				return false;
+			}
 		}
-		if (local_dir.empty() && remote_dir_raw.empty())
+		if (local_dir.empty() && remote_dir_raw.empty()) {
 			return false;
+		}
 
-		if (local_dir.empty() || remote_dir_raw.empty())
+		if (local_dir.empty() || remote_dir_raw.empty()) {
 			sync = false;
-		else
+		}
+		else {
 			sync = GetTextElementBool(bookmark, "SyncBrowsing", false);
+		}
 
 		comparison = GetTextElementBool(bookmark, "DirectoryComparison", false);
 		return true;
