@@ -35,14 +35,14 @@ void CLocalRecursiveOperation::AddRecursionRoot(local_recursion_root && root)
 	}
 }
 
-void CLocalRecursiveOperation::StartRecursiveOperation(OperationMode mode, std::vector<CFilter> const& filters)
+void CLocalRecursiveOperation::StartRecursiveOperation(OperationMode mode, ActiveFilters const& filters, bool immediate)
 {
-	if (!DoStartRecursiveOperation(mode, filters)) {
+	if (!DoStartRecursiveOperation(mode, filters, immediate)) {
 		StopRecursiveOperation();
 	}
 }
 
-bool CLocalRecursiveOperation::DoStartRecursiveOperation(OperationMode mode, std::vector<CFilter> const& filters)
+bool CLocalRecursiveOperation::DoStartRecursiveOperation(OperationMode mode, ActiveFilters const& filters, bool immediate)
 {
 	if (!m_pQueue) {
 		return false;
@@ -77,6 +77,7 @@ bool CLocalRecursiveOperation::DoStartRecursiveOperation(OperationMode mode, std
 		m_processedFiles = 0;
 		m_processedDirectories = 0;
 
+		m_immediate = immediate;
 		m_operationMode = mode;
 
 		m_filters = filters;
@@ -87,6 +88,10 @@ bool CLocalRecursiveOperation::DoStartRecursiveOperation(OperationMode mode, std
 		}
 	}
 
+	if ((mode == CRecursiveOperation::recursive_transfer || mode == CRecursiveOperation::recursive_transfer_flatten) && immediate) {
+		m_actionAfterBlocker = m_pQueue->GetActionAfterBlocker();
+	}
+
 	m_state.NotifyHandlers(STATECHANGE_LOCAL_RECURSION_STATUS);
 
 	return true;
@@ -112,9 +117,11 @@ void CLocalRecursiveOperation::StopRecursiveOperation()
 	m_listedDirectories.clear();
 
 	m_state.NotifyHandlers(STATECHANGE_LOCAL_RECURSION_STATUS);
+
+	m_actionAfterBlocker.reset();
 }
 
-void CLocalRecursiveOperation::OnStateChange(t_statechange_notifications notification, const wxString&, const void* data2)
+void CLocalRecursiveOperation::OnStateChange(t_statechange_notifications, const wxString&, const void*)
 {
 }
 
@@ -134,7 +141,7 @@ void CLocalRecursiveOperation::EnqueueEnumeratedListing(fz::scoped_lock& l, list
 
 		CServerPath remoteSub = d.remotePath;
 		if (!remoteSub.empty()) {
-			if (m_operationMode == recursive_transfer || m_operationMode == recursive_addtoqueue) {
+			if (m_operationMode == recursive_transfer) {
 				// Non-flatten case
 				remoteSub.AddSegment(entry.name);
 			}
@@ -157,7 +164,7 @@ void CLocalRecursiveOperation::entry()
 	{
 		fz::scoped_lock l(mutex_);
 
-		auto filters = m_filters;
+		auto filters = m_filters.first;
 
 		CFilterManager filterManager;
 		filterManager.CompileRegexes(filters);
@@ -250,8 +257,7 @@ void CLocalRecursiveOperation::OnListedDirectory()
 		return;
 	}
 
-	bool const queue = m_operationMode == recursive_addtoqueue || m_operationMode == recursive_addtoqueue_flatten || m_operationMode == recursive_transfer || m_operationMode == recursive_addtoqueue_flatten;
-	bool const queueOnly = m_operationMode == recursive_addtoqueue || m_operationMode == recursive_addtoqueue_flatten;
+	bool const queue = m_operationMode == recursive_transfer || m_operationMode == recursive_transfer_flatten;
 
 	listing d;
 
@@ -269,11 +275,11 @@ void CLocalRecursiveOperation::OnListedDirectory()
 		}
 
 		if (d.localPath.empty()) {
-			StopRecursiveOperation();
+			stop = true;
 		}
 		else {
 			if (queue) {
-				m_pQueue->QueueFiles(queueOnly, server_, d);
+				m_pQueue->QueueFiles(!m_immediate, server_, d);
 			}
 			++m_processedDirectories;
 			processed += d.files.size();
@@ -282,7 +288,7 @@ void CLocalRecursiveOperation::OnListedDirectory()
 	}
 
 	if (queue) {
-		m_pQueue->QueueFile_Finish(!queueOnly);
+		m_pQueue->QueueFile_Finish(m_immediate);
 	}
 	
 	m_processedFiles += processed;
