@@ -146,8 +146,8 @@ class CFileItem : public CQueueItem
 {
 public:
 	CFileItem(CServerItem* parent, bool queued, bool download,
-		const wxString& sourceFile, const wxString& targetFile,
-		const CLocalPath& localPath, const CServerPath& remotePath, int64_t size);
+		std::wstring const& sourceFile, std::wstring const& targetFile,
+		CLocalPath const& localPath, CServerPath const& remotePath, int64_t size);
 
 	virtual ~CFileItem();
 
@@ -270,8 +270,8 @@ protected:
 class CFolderItem : public CFileItem
 {
 public:
-	CFolderItem(CServerItem* parent, bool queued, const CLocalPath& localPath);
-	CFolderItem(CServerItem* parent, bool queued, const CServerPath& remotePath, const wxString& remoteFile);
+	CFolderItem(CServerItem* parent, bool queued, CLocalPath const& localPath);
+	CFolderItem(CServerItem* parent, bool queued, CServerPath const& remotePath, std::wstring const& remoteFile);
 
 	virtual QueueItemType GetType() const { return QueueItemType::Folder; }
 
@@ -352,11 +352,11 @@ protected:
 	void DisplayNumberQueuedFiles();
 
 	// Position at which insertions start and number of insertions
-	int m_insertionStart;
-	unsigned int m_insertionCount;
+	int m_insertionStart{-1};
+	unsigned int m_insertionCount{};
 
-	int m_fileCount;
-	bool m_fileCountChanged;
+	int m_fileCount{};
+	bool m_fileCountChanged{};
 
 	// Selection management.
 	void UpdateSelections_ItemAdded(int added);
@@ -364,8 +364,8 @@ protected:
 	void UpdateSelections_ItemRemoved(int removed);
 	void UpdateSelections_ItemRangeRemoved(int removed, int count);
 
-	int m_itemCount;
-	bool m_allowBackgroundErase;
+	int m_itemCount{};
+	bool m_allowBackgroundErase{true};
 
 	std::vector<CServerItem*> m_serverList;
 
