@@ -131,7 +131,7 @@ private:
 // -----------------------
 
 // Defined in RemoteListView.cpp
-extern wxString StripVMSRevision(const wxString& name);
+std::wstring StripVMSRevision(std::wstring const& name);
 
 CSearchDialogFileList::CSearchDialogFileList(CSearchDialog* pParent, CQueueView* pQueue)
 	: CFileListCtrl<CGenericFileData>(pParent, pQueue, true),
@@ -645,7 +645,7 @@ void CSearchDialog::OnSearch(wxCommandEvent&)
 			return;
 		}
 
-		wxString error;
+		std::wstring error;
 		if (!path.Exists(&error)) {
 			wxMessageBoxEx(error, _("Local file search"), wxICON_EXCLAMATION);
 			return;
@@ -667,7 +667,7 @@ void CSearchDialog::OnSearch(wxCommandEvent&)
 			return;
 		}
 		path.SetType(pServer->GetType());
-		if (!path.SetPath(xrc_call(*this, "ID_PATH", &wxTextCtrl::GetValue)) || path.empty()) {
+		if (!path.SetPath(xrc_call(*this, "ID_PATH", &wxTextCtrl::GetValue).ToStdWstring()) || path.empty()) {
 			wxMessageBoxEx(_("Need to enter valid remote path"), _("Remote file search"), wxICON_EXCLAMATION);
 			return;
 		}
@@ -708,7 +708,7 @@ void CSearchDialog::OnSearch(wxCommandEvent&)
 	}
 	else {
 		recursion_root root(m_remote_search_root, true);
-		root.add_dir_to_visit_restricted(m_remote_search_root, _T(""), true);
+		root.add_dir_to_visit_restricted(m_remote_search_root, std::wstring(), true);
 		m_state.GetRemoteRecursiveOperation()->AddRecursionRoot(std::move(root));
 		ActiveFilters const filters; // Empty, recurse into everything
 		m_state.GetRemoteRecursiveOperation()->StartRecursiveOperation(CRecursiveOperation::recursive_list, filters, m_remote_search_root);
@@ -854,7 +854,7 @@ void CSearchTransferDialog::OnOK(wxCommandEvent&)
 	if (download_) {
 		wxTextCtrl *pText = XRCCTRL(*this, "ID_LOCALPATH", wxTextCtrl);
 
-		CLocalPath path(pText->GetValue());
+		CLocalPath path(pText->GetValue().ToStdWstring());
 		if (path.empty()) {
 			wxMessageBoxEx(_("You have to enter a local directory."), _("Download search results"), wxICON_EXCLAMATION);
 			return;
@@ -868,7 +868,7 @@ void CSearchTransferDialog::OnOK(wxCommandEvent&)
 	else {
 		wxTextCtrl *pText = XRCCTRL(*this, "ID_REMOTEPATH", wxTextCtrl);
 
-		CServerPath path(pText->GetValue());
+		CServerPath path(pText->GetValue().ToStdWstring());
 		if (path.empty()) {
 			wxMessageBoxEx(_("You have to enter a remote directory."), _("Upload search results"), wxICON_EXCLAMATION);
 			return;
@@ -965,7 +965,7 @@ void CSearchDialog::OnDownload(wxCommandEvent&)
 
 	wxTextCtrl *pText = XRCCTRL(dlg, "ID_LOCALPATH", wxTextCtrl);
 
-	CLocalPath path(pText->GetValue());
+	CLocalPath path(pText->GetValue().ToStdWstring());
 	if (path.empty() || !path.IsWriteable()) {
 		wxBell();
 		return;
@@ -987,7 +987,7 @@ void CSearchDialog::OnDownload(wxCommandEvent&)
 		if (!flatten) {
 			// Append relative path to search root to local target path
 			CServerPath remote_path = entry.path;
-			std::list<wxString> segments;
+			std::list<std::wstring> segments;
 			while (m_remote_search_root.IsParentOf(remote_path, false) && remote_path.HasParent()) {
 				segments.push_front(remote_path.GetLastSegment());
 				remote_path = remote_path.GetParent();
@@ -998,12 +998,12 @@ void CSearchDialog::OnDownload(wxCommandEvent&)
 		}
 
 		CServerPath remote_path = entry.path;
-		wxString localName = CQueueView::ReplaceInvalidCharacters(entry.name);
+		std::wstring localName = CQueueView::ReplaceInvalidCharacters(entry.name);
 		if (!entry.is_dir() && remote_path.GetType() == VMS && COptions::Get()->GetOptionVal(OPTION_STRIP_VMS_REVISION))
 			localName = StripVMSRevision(localName);
 
 		m_pQueue->QueueFile(!start, true,
-			entry.name, (localName != entry.name) ? localName : wxString(),
+			entry.name, (localName != entry.name) ? localName : std::wstring(),
 			target_path, remote_path, *pServer, entry.size);
 	}
 	m_pQueue->QueueFile_Finish(start);
@@ -1017,7 +1017,7 @@ void CSearchDialog::OnDownload(wxCommandEvent&)
 		}
 
 		recursion_root root(dir, true);
-		root.add_dir_to_visit(dir, _T(""), target_path, false);
+		root.add_dir_to_visit(dir, std::wstring(), target_path, false);
 		m_state.GetRemoteRecursiveOperation()->AddRecursionRoot(std::move(root));
 	}
 	ActiveFilters const filters; // Empty, recurse into everything
@@ -1045,7 +1045,7 @@ void CSearchDialog::OnUpload(wxCommandEvent&)
 
 	wxTextCtrl *pText = XRCCTRL(dlg, "ID_REMOTEPATH", wxTextCtrl);
 
-	CServerPath path(pText->GetValue());
+	CServerPath path(pText->GetValue().ToStdWstring());
 	if (path.empty()) {
 		wxBell();
 		return;
@@ -1067,7 +1067,7 @@ void CSearchDialog::OnUpload(wxCommandEvent&)
 		if (!flatten) {
 			// Append relative path to search root to local target path
 			CLocalPath local_path = entry.path;
-			std::list<wxString> segments;
+			std::list<std::wstring> segments;
 			while (m_local_search_root.IsParentOf(local_path) && local_path.HasParent()) {
 				segments.push_front(local_path.GetLastSegment());
 				local_path = local_path.GetParent();
@@ -1078,10 +1078,10 @@ void CSearchDialog::OnUpload(wxCommandEvent&)
 		}
 
 		CLocalPath local_path = entry.path;
-		wxString localName = CQueueView::ReplaceInvalidCharacters(entry.name);
+		std::wstring localName = CQueueView::ReplaceInvalidCharacters(entry.name);
 
 		m_pQueue->QueueFile(!start, false,
-			entry.name, (localName != entry.name) ? localName : wxString(),
+			entry.name, (localName != entry.name) ? localName : std::wstring(),
 			local_path, target_path, *pServer, entry.size);
 	}
 	m_pQueue->QueueFile_Finish(start);
@@ -1200,7 +1200,7 @@ void CSearchDialog::OnDelete(wxCommandEvent&)
 	}
 
 	for (auto path : selected_dirs) {
-		wxString segment;
+		std::wstring segment;
 		if (path.HasParent()) {
 			segment = path.GetLastSegment();
 			path = path.GetParent();
